@@ -22,7 +22,7 @@ from botocore.config import Config
 from common.schedulers.slurm_commands import resume_powering_down_nodes, update_all_partitions
 from slurm_plugin.clustermgtd import ComputeFleetStatus, ComputeFleetStatusManager
 from slurm_plugin.common import log_exception
-from slurm_plugin.instance_manager import InstanceManagerFactory
+from slurm_plugin.instance_manager import InstanceManager
 from slurm_plugin.slurm_resources import CONFIG_FILE_DIR, PartitionStatus
 
 log = logging.getLogger(__name__)
@@ -100,7 +100,7 @@ def _start_partitions():
 def _stop_partitions(config):
     log.info("Setting slurm partitions to INACTIVE and terminating all compute nodes...")
     update_all_partitions(PartitionStatus.INACTIVE, reset_node_addrs_hostname=True)
-    instance_manager = InstanceManagerFactory.get_manager(
+    instance_manager = InstanceManager(
         config.region,
         config.cluster_name,
         config.boto3_config,
